@@ -279,11 +279,10 @@ sub new {
 
         if ( !$object ) {
             $object = _object_factory( $block, $value ) unless $object;
-        } elsif ($object->can($attribute)) {
+        } elsif ( $object->can($attribute) ) {
             $object->$attribute($value);
         } else {
-            warn "Objects of type " . ref($object)
-                . " do not support attribute '$attribute', but it was supplied with value '$value'\n";
+            warn "Objects of type " . ref($object) . " do not support attribute '$attribute', but it was supplied with value '$value'\n";
         }
 
     }
@@ -571,31 +570,28 @@ sub syncupdates_create {
 
     if (    $res =~ /^Number of objects processed with errors:\s+(\d+)/m
          && $1 == 0
-         && (
-                 $res =~ /\*\*\*Info:\s+Authorisation for\s+\[[^\]]+]\s+(.+)\s*$/m
-              || $res =~ /(?:Create SUCCEEDED|No operation): \[[^\]]+\]\s+(\S+)/m
-            )
-       )
+         && (    $res =~ /\*\*\*Info:\s+Authorisation for\s+\[[^\]]+]\s+(.+)\s*$/m
+              || $res =~ /(?:Create SUCCEEDED|No operation): \[[^\]]+\]\s+(\S+)/m )
+        )
     {
         my $value = $1;
-        my ( $key ) = $self->attributes( 'primary' );
+        my ($key) = $self->attributes('primary');
+
         # some primary keys can contain spaces, in which case $value
         # is not correct. So only use it for objects where the primary
         # key can be generated by the RIPE DB, and where it never contains
         # spaces. According to
         # http://www.ripe.net/ripe/mail/archives/db-help/2013-January/000411.html
         # this is the case for person, organization, role and key-cert
-        my %obj_types_with_autogen_key = (
-            KeyCert      => 1,
-            Organisation => 1,
-            Person       => 1,
-            Role         => 1,
+        my %obj_types_with_autogen_key = ( KeyCert      => 1,
+                                           Organisation => 1,
+                                           Person       => 1,
+                                           Role         => 1,
         );
-        if ($self->class && $obj_types_with_autogen_key{$self->class}) {
+        if ( $self->class && $obj_types_with_autogen_key{ $self->class } ) {
             $self->_single_attribute_setget( $key, $value );
             return $value;
-        }
-        else {
+        } else {
             return $self->$key();
         }
     } else {
@@ -730,13 +726,37 @@ Generic setter/getter for singlevalue attribute.
 
 sub _single_attribute_setget {
     my ( $self, $attribute, $value ) = @_;
+    my $mode = 'replace';
+
+    if ( ref $value eq 'HASH' ) {
+        my %options = %$value;
+
+        if ( $options{mode} ) {
+            $mode = $options{mode};
+        }
+
+        if ( $options{value} ) {
+            $value = $options{value};
+        } else {
+            croak "Unable to determine attribute $attribute value";
+        }
+
+    }
 
     if ( defined $value ) {
 
-        # Store attribute order for dump, unless this attribute as already been set
-        push @{ $self->{order} }, $attribute unless $self->{$attribute} or $attribute eq 'class';
+        if ( $mode eq 'replace' ) {
+            # Store attribute order for dump, unless this attribute as already been set
+            push @{ $self->{order} }, $attribute unless $self->{$attribute} or $attribute eq 'class';
 
-        $self->{$attribute} = $value;
+            $self->{$attribute} = $value;
+        } elsif ( $mode eq 'delete' ) {
+            if ( ref $value ne 'HASH' or !$value->{old} ) {
+                croak " {old=>...} expected as value for $attribute update in delete mode";
+            } else {
+                $self->_delete_attribute($attribute,$value->{old});
+            }
+        }
     }
     return $self->{$attribute};
 }
@@ -791,8 +811,8 @@ sub _multiple_attribute_setget {
             if ( ref $value ne 'HASH' or !$value->{old} ) {
                 croak " {old=>...} expected as value for $attribute update in delete mode";
             } else {
-                my $old = $value->{old};
-                $self->{$attribute} = [grep {!/$old/} @{$self->{$attribute}}];
+                # $self->{$attribute} = [grep {!/$old/} @{$self->{$attribute}}];
+                $self->_delete_attribute($attribute,$value->{old});
             }
         } else {
             croak "Unknown mode $mode for attribute $attribute";
@@ -803,6 +823,45 @@ sub _multiple_attribute_setget {
     return $self->{$attribute};
 }
 
+=head2 B<_delete_attribute( $attribute, $pattern )>
+
+Delete an attribute if its value match the pattern value 
+
+=cut
+
+sub _delete_attribute {
+    my ( $self, $attribute, $pattern ) = @_;
+
+                my @lines;
+
+                for my $a ( @{ $self->{order} } ) {
+                    my $val = ref $self->{$a} ? shift @{ $self->{$a} } : $self->{$a};
+                    push @lines, [ $a, $val ];
+                }
+
+                @lines = grep {$attribute ne $_->[0] or $_->[1] !~ /$pattern/} @lines;
+                delete $self->{$attribute}  if $self->attribute_is($attribute, 'single') and $self->{$attribute} =~ /$pattern/;
+
+                $self->{order} = [];
+                for my $l (@lines) {
+                        $self->{ $l->[0] } = []     if  ref( $self->{ $l->[0] } )  ;
+                }
+
+                for my $i ( 0 .. $#lines ) {
+                    push @{ $self->{order} }, $lines[$i]->[0];
+                    if ( $self->attribute_is( $lines[$i]->[0], 'multiple' ) ) {
+                        push @{ $self->{ $lines[$i]->[0] } }, $lines[$i]->[1];
+                    } else {
+                        $self->{ $lines[$i]->[0] } = $lines[$i]->[1];
+
+                    }
+
+                }
+
+}
+
+
+
 =head2 B<_init( @options )>
 
 Initialize self with C<@options>
